@@ -1,7 +1,7 @@
 package Sah::Schema::ean8;
 
 our $DATE = '2018-08-23'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 our $schema = [str => {
     summary => 'EAN-8 number',
@@ -13,7 +13,7 @@ Checksum digit must be valid.
 
 _
     match => '\A[0-9]{8}\z',
-    'x.perl.coerce_rules' => ['str_ean8'],
+    'x.perl.coerce_rules' => ['str_to_ean8'],
 }, {}];
 
 1;
@@ -31,7 +31,7 @@ Sah::Schema::ean8 - EAN-8 number
 
 =head1 VERSION
 
-This document describes version 0.001 of Sah::Schema::ean8 (from Perl distribution Sah-Schemas-EAN), released on 2018-08-23.
+This document describes version 0.002 of Sah::Schema::ean8 (from Perl distribution Sah-Schemas-EAN), released on 2018-08-23.
 
 =head1 DESCRIPTION
 
